@@ -92,8 +92,7 @@ outmap.plot(axes=ax2, title='EUVI image as seen from SDO')
 map_euvi.draw_limb(color='blue')
 
 # Set the HPC grid color to black as the background is white
-ax2.coords[0].grid_lines_kwargs['edgecolor'] = 'k'
-ax2.coords[1].grid_lines_kwargs['edgecolor'] = 'k'
+ax2.grid(color='k')
 
 ######################################################################
 # AIA as Seen from Mars
