@@ -12,7 +12,6 @@ This example shows how to plot two maps on top of each other, with a slider to
 fade between them. Note that it assumes that the two maps are taken at the same
 time from the same observation point.
 """
-
 import matplotlib.pyplot as plt
 from matplotlib.widgets import Slider
 
@@ -37,11 +36,10 @@ map_1600 = sunpy.map.Map(AIA_1600_IMAGE)
 # contains the slider.
 
 fig = plt.figure()
-
 # Add the main axes. Note this is resized to leave room for the slider axes
 ax = fig.add_axes([0.1, 0.2, 0.9, 0.7], projection=map_171)
 
-im_1600 = map_1600.plot(axes=ax)
+im_1600 = map_1600.plot(axes=ax, autoalign=True)
 im_171 = map_171.plot(axes=ax, alpha=0.5, clip_interval=(1, 99.99)*u.percent)
 ax.set_title('AIA 171 + 1600')
 
@@ -49,12 +47,12 @@ ax.set_title('AIA 171 + 1600')
 ax_slider = fig.add_axes([0.25, 0.05, 0.65, 0.03])
 slider = Slider(ax_slider, 'Alpha', 0, 1, valinit=0.5)
 
-
 ###############################################################################
 # Finally, define what happens when the slider is changed and link this to the
 # slider we set up above. In this case we just set the alpha (ie. transparency)
 # of the 171 image.
 
+
 def update(val):
     alpha = slider.val
     im_171.set_alpha(alpha)
