@@ -33,16 +33,18 @@ from sunpy.coordinates import (
     HeliographicCarrington,
     HeliographicStonyhurst,
     Helioprojective,
+    HelioprojectiveRadial,
     SolarMagnetic,
+    SphericalScreen,
     propagate_with_solar_surface,
     sun,
     transform_with_sun_center,
 )
 from sunpy.coordinates.ephemeris import get_body_heliographic_stonyhurst, get_earth
 from sunpy.coordinates.frames import _J2000
-from sunpy.physics.differential_rotation import diff_rot
 from sunpy.sun.constants import radius as _RSUN
 from sunpy.sun.constants import sidereal_rotation_rate
+from sunpy.sun.models import differential_rotation
 from sunpy.time import parse_time
 
 
@@ -120,6 +122,64 @@ def test_hpc_hpc_null():
     assert hpc_out.observer == hpc_new.observer
 
 
+@pytest.mark.parametrize(('Tx', 'Ty', 'psi', 'delta', 'theta'),
+                         [(0*u.arcsec, 0*u.arcsec, 0*u.deg, -90*u.deg, 0*u.arcsec),
+                          (360*u.arcsec, 0*u.arcsec, 270*u.deg, -89.9*u.deg, 360*u.arcsec),
+                          (0*u.arcsec, -720*u.arcsec, 180*u.deg, -89.8*u.deg, 720*u.arcsec),
+                          (360*u.arcsec, -720*u.arcsec, 206.564946*u.deg, -89.776393*u.deg, 804.984145*u.arcsec)])
+def test_hpc_hpr(Tx, Ty, psi, delta, theta):
+    observer = HeliographicStonyhurst(0*u.deg, 0*u.deg, radius=1*u.AU)
+    hpc = Helioprojective(Tx, Ty, observer=observer)
+
+    hpr = hpc.transform_to(HelioprojectiveRadial(observer=observer))
+    assert_quantity_allclose(hpr.psi, psi)
+    assert_quantity_allclose(hpr.delta, delta)
+    assert_quantity_allclose(hpr.theta, theta)
+
+    hpc_back = hpr.transform_to(hpc)
+    assert_quantity_allclose(hpc_back.Tx, Tx)
+    assert_quantity_allclose(hpc_back.Ty, Ty)
+
+
+def test_hpc_hpc_spherical_screen():
+    D0 = 20*u.R_sun
+    L0 = 67.5*u.deg
+    Tx0 = 45*u.deg
+    observer_in = HeliographicStonyhurst(lat=0*u.deg, lon=0*u.deg, radius=D0)
+    # Once our coordinate is placed on the screen, observer_out will be looking
+    # directly along the line containing itself, the coordinate, and the Sun
+    observer_out = HeliographicStonyhurst(lat=0*u.deg, lon=L0, radius=2*D0)
+
+    sc_in = SkyCoord(Tx0, 0*u.deg, observer=observer_in,
+                     frame='helioprojective')
+
+    with SphericalScreen(observer_in):
+        sc_3d = sc_in.make_3d()
+        sc_out = sc_in.transform_to(Helioprojective(observer=observer_out))
+
+    assert quantity_allclose(sc_3d.distance, D0)
+
+    assert quantity_allclose(sc_out.Tx, 0*u.deg, atol=1e-6*u.deg)
+    assert quantity_allclose(sc_out.Ty, 0*u.deg, atol=1e-6*u.deg)
+    # Law of Cosines to compute the coordinate's distance from the Sun, and then
+    # r_expected is the distance from observer_out to the coordinate
+    radius_expected = 2 * D0 - np.sqrt(2 * D0**2 - 2 * D0 * D0 * np.cos(45*u.deg))
+    assert quantity_allclose(sc_out.distance, radius_expected)
+
+    # Now test with a very large screen, letting us approximate the two
+    # observers as being the same (aside from a different zero point for Tx)
+    r_s = 1e9 * u.lightyear
+    with SphericalScreen(observer_in, radius=r_s):
+        sc_3d = sc_in.make_3d()
+        sc_out = sc_in.transform_to(Helioprojective(observer=observer_out))
+
+    assert quantity_allclose(sc_3d.distance, r_s)
+
+    assert quantity_allclose(sc_out.Tx, Tx0 + L0)
+    assert quantity_allclose(sc_out.Ty, 0*u.deg)
+    assert quantity_allclose(sc_out.distance, r_s)
+
+
 def test_hcrs_hgs():
     # Get the current Earth location in HCRS
     adate = parse_time('2015/05/01 01:13:00')
@@ -1101,14 +1161,14 @@ def test_propagate_with_solar_surface():
     # Using the context manager (also test default rotation model is 'howard')
     with propagate_with_solar_surface():
         result2 = meridian.transform_to(end_frame)
-    assert u.allclose(result2.lon, diff_rot(dt, meridian.lat, rot_type='howard'))
+    assert u.allclose(result2.lon, differential_rotation(dt, meridian.lat, model='howard'))
 
     # Check that nesting the context manager doesn't confuse anything (also test other models)
     with propagate_with_solar_surface('snodgrass'):
         with propagate_with_solar_surface('allen'):
             pass
         result3 = meridian.transform_to(end_frame)  # should use 'snodgrass', not 'allen'
-    assert u.allclose(result3.lon, diff_rot(dt, meridian.lat, rot_type='snodgrass'))
+    assert u.allclose(result3.lon, differential_rotation(dt, meridian.lat, model='snodgrass'))
 
     # After the context manager, the coordinate should have the same result as the first transform
     result4 = meridian.transform_to(end_frame)
