@@ -8,7 +8,7 @@ from sunpy import log
 from sunpy.coordinates import frames, sun
 from sunpy.util import MetaDict
 
-__all__ = ['make_fitswcs_header', 'get_observer_meta', 'make_heliographic_header']
+__all__ = ['make_fitswcs_header', 'get_observer_meta', 'make_heliographic_header', 'make_hpr_header']
 
 
 @u.quantity_input(equivalencies=u.spectral())
@@ -193,8 +193,8 @@ def _set_transform_params(meta_wcs, coordinate, reference_pixel, scale, shape):
     meta_wcs['crpix1'], meta_wcs['crpix2'] = (reference_pixel[0].to_value(u.pixel) + 1,
                                               reference_pixel[1].to_value(u.pixel) + 1)
 
-    meta_wcs['cdelt1'] = scale[0].to_value(meta_wcs['cunit1']/u.pixel)
-    meta_wcs['cdelt2'] = scale[1].to_value(meta_wcs['cunit2']/u.pixel)
+    meta_wcs['cdelt1'] = scale[0].to_value(u.Unit(meta_wcs['cunit1']) / u.pixel)
+    meta_wcs['cdelt2'] = scale[1].to_value(u.Unit(meta_wcs['cunit2']) / u.pixel)
     return meta_wcs
 
 
@@ -391,3 +391,97 @@ def make_heliographic_header(date, observer_coordinate, shape, *, frame, project
 
     header = make_fitswcs_header(shape, frame_out, scale=scale, projection_code=projection_code)
     return header
+
+
+@u.quantity_input
+def make_hpr_header(observer_coordinate, shape, theta_binsize: u.Quantity[u.arcsec], *,
+                    theta_min: u.Quantity[u.arcsec] = 0.0*u.arcsec,
+                    psi_center: u.Quantity[u.deg] = 180.0*u.deg):
+    """
+    Construct a FITS-WCS header for a helioprojective radial coordinate frame.
+
+    The header uses the plate carrée projection ("CAR" in FITS-WCS) with the
+    position angle (``psi``) on the horizontal axis and impact angle (``theta``) on
+    the vertical axis.  To accommodate the FITS-WCS machinery, the vertical axis is
+    actually the declination (``delta``), which is the impact angle minus 90 degrees.
+
+    Parameters
+    ----------
+    observer_coordinate :
+        Observer coordinate, with corresponding observation time.
+    shape : [int, int]
+        Output map shape, number of pixels in (theta, psi).
+    theta_binsize : `~astropy.units.Quantity`
+        The size of each pixel in the impact-angle direction.
+    theta_min : `~astropy.units.Quantity`
+        The minimum impact angle.  Defaults to 0 arcsec.
+    psi_center : `~astropy.units.Quantity`
+        The center of the map in position angle.  Defaults to 180 degrees.
+
+    Returns
+    -------
+    `~sunpy.util.MetaDict`
+
+    See Also
+    --------
+    sunpy.map.header_helper.make_fitswcs_header : A more generic header helper that can be used if more customisation is required.
+    sunpy.coordinates.HelioprojectiveRadial : The coordinate-frame class
+
+    Examples
+    --------
+    >>> import astropy.units as u
+    >>> from sunpy.coordinates import get_earth
+
+    >>> observer = get_earth('2024-09-16 01:02:03')
+    >>> make_hpr_header(observer, (180, 360), theta_binsize=10*u.arcsec)
+    MetaDict([('wcsaxes': '2')
+    ('crpix1': '180.5')
+    ('crpix2': '32400.5')
+    ('cdelt1': '1.0')
+    ('cdelt2': '10.0')
+    ('cunit1': 'deg')
+    ('cunit2': 'arcsec')
+    ('ctype1': 'HRLN-CAR')
+    ('ctype2': 'HRLT-CAR')
+    ('crval1': '180.0')
+    ('crval2': '0.0')
+    ('lonpole': '0.0')
+    ('latpole': '90.0')
+    ('mjdref': '0.0')
+    ('date-obs': '2024-09-16T01:02:03.000')
+    ('rsun_ref': '695700000.0')
+    ('dsun_obs': '150399816551.15')
+    ('hgln_obs': '0.0')
+    ('hglt_obs': '7.1884873184853')
+    ('naxis': '2')
+    ('naxis1': '360')
+    ('naxis2': '180')
+    ('pc1_1': '1.0')
+    ('pc1_2': '-0.0')
+    ('pc2_1': '0.0')
+    ('pc2_2': '1.0')
+    ('rsun_obs': '954.1164393469891')])
+
+    .. minigallery:: sunpy.map.make_hpr_header
+    """
+    # The reference coord must be on the equator (delta = 0 deg)
+    reference_coord = SkyCoord(
+        psi_center,
+        0*u.deg,
+        frame="helioprojectiveradial",
+        obstime=observer_coordinate.obstime,
+        observer=observer_coordinate,
+        rsun=getattr(observer_coordinate, "rsun", None),
+    )
+
+    # Calculate the correct location for this reference coord, which will likely be far off the data array
+    reference_pixel = [
+        shape[1] / 2. - 0.5,
+        ((90*u.deg - theta_min) / theta_binsize).to_value(u.one) - 0.5
+    ] * u.pix
+
+    scale = u.Quantity([360*u.deg / int(shape[1]), theta_binsize]) / u.pix
+
+    header = make_fitswcs_header(shape, reference_coord, reference_pixel=reference_pixel,
+                                 scale=scale, projection_code="CAR")
+    return header
