@@ -28,15 +28,17 @@ class SWAPMap(GenericMap):
     def __init__(self, data, header, **kwargs):
         super().__init__(data, header, **kwargs)
 
-        # It needs to be verified that these must actually be set and
-        # are not already in the header.
-        self.meta['detector'] = "SWAP"
-#        self.meta['instrme'] = "SWAP"
-        self.meta['obsrvtry'] = "PROBA2"
-
         self._nickname = self.detector
         self.plot_settings['cmap'] = 'sdoaia171'
 
+    @property
+    def observatory(self):
+        return "PROBA2"
+
+    @property
+    def detector(self):
+        return "SWAP"
+
     @classmethod
     def is_datasource_for(cls, data, header, **kwargs):
         """Determines if header corresponds to an SWAP image"""
