@@ -26,7 +26,7 @@ class EUIMap(GenericMap):
     References
     ----------
     * `Solar Orbiter Mission Page <https://sci.esa.int/web/solar-orbiter/>`__
-    * `EUI Instrument Page <https://wwwbis.sidc.be/EUI/EUI/EUI/EUI/EUI/>`__
+    * `EUI Instrument Page <https://www.sidc.be/EUI/about/instrument>`__
     * `Instrument Paper <https://doi.org/10.1051/0004-6361/201936663>`__
     """
 
@@ -46,11 +46,6 @@ class EUIMap(GenericMap):
             # The level number is prepended by the letter L
             return int(self.meta.get('level')[1:])
 
-    @property
-    def date(self):
-        # Prioritize date-average over date-obs
-        return self.date_average or super().date
-
     @property
     def waveunit(self):
         # EUI JP2000 files do not have the WAVEUNIT key in the metadata.
