@@ -4,6 +4,7 @@ import pytest
 import astropy.units as u
 
 from sunpy.data.test import get_dummy_map_from_header, get_test_filepath
+from sunpy.map.mapbase import SpatialPair
 from sunpy.map.sources.hinode import SOTMap
 from sunpy.util.exceptions import SunpyMetadataWarning
 from .helpers import _test_private_date_setters
@@ -19,6 +20,10 @@ def test_fitstoSOT(sot):
     assert isinstance(sot, SOTMap)
 
 
+def test_sot_coordinate_system(sot):
+    assert sot.coordinate_system ==  SpatialPair(axis1='HPLN-TAN', axis2='HPLT-TAN')
+
+
 def test_is_datasource_for(sot):
     """Test the is_datasource_for method of SOTMap.
     Note that header data to be provided as an argument
