@@ -26,6 +26,7 @@ AIA_171_IMAGE = get_test_filepath('aia_171_level1.fits')
 RHESSI_IMAGE = get_test_filepath('hsi_image_20101016_191218.fits')
 AIA_193_JP2 = get_test_filepath("2013_06_24__17_31_30_84__SDO_AIA_AIA_193.jp2")
 HMI_LOS_JP2 = get_test_filepath("2023_01_31__03_39_23_200__SDO_HMI_HMI_continuum.jp2")
+AIA_ASDF = get_test_filepath("aiamap_genericmap_1.0.0.asdf")
 AIA_MAP = sunpy.map.Map(AIA_171_IMAGE)
 VALID_MAP_INPUTS = [
     (AIA_171_IMAGE, ),
@@ -50,6 +51,13 @@ def test_two_map_inputs(args1, args2):
         assert isinstance(out, sunpy.map.GenericMap)
 
 
+def test_read_asdf_and_verify(tmpdir):
+    loaded_asdf_map = sunpy.map.Map(AIA_ASDF)
+    assert isinstance(loaded_asdf_map.data, np.ndarray)
+    assert isinstance(loaded_asdf_map.meta, dict)
+    assert isinstance(loaded_asdf_map, sunpy.map.sources.AIAMap)
+
+
 def test_mapsequence(eit_fits_directory):
     # Test making a MapSequence
     sequence = sunpy.map.Map(list(eit_fits_directory.glob('*.fits')), sequence=True)
@@ -246,6 +254,22 @@ def test_url_pattern():
     amap = sunpy.map.Map("http://data.sunpy.org/sample-data/AIA20110319_105400_0171.fits")
     assert isinstance(amap, sunpy.map.GenericMap)
 
+@pytest.mark.remote_data
+def test_uri_pattern():
+    """
+    Testing publicly accessible s3 object
+    """
+    amap = sunpy.map.Map("s3://data.sunpy.org/sunpy/AIA20110607_065843_0193_cutout.fits", fsspec_kwargs={"anon": True})
+    assert isinstance(amap, sunpy.map.GenericMap)
+
+@pytest.mark.remote_data
+def test_uri_directory_pattern():
+    """
+    Testing publicly accessible s3 directory
+    """
+    with pytest.warns(SunpyUserWarning, match='Failed to read'):
+        amap = sunpy.map.Map('s3://data.sunpy.org/aiapy', fsspec_kwargs={'anon':True}, allow_errors=True)
+        assert all(isinstance(am, sunpy.map.GenericMap) for am in amap)
 
 def test_save():
     # Test save out
@@ -267,6 +291,15 @@ def test_map_list_urls_cache():
     with pytest.warns(fits.verify.VerifyWarning, match="Invalid 'BLANK' keyword in header."):
         sunpy.map.Map(urls)
 
+@pytest.mark.remote_data
+def test_map_list_uri():
+    """
+    Test for reading from URI (AWS S3).
+    """
+    uri_list = ["s3://data.sunpy.org/aiapy/aia_lev1_171a_2019_01_01t00_00_09_35z_image_lev1.fits",
+                "s3://data.sunpy.org/aiapy/aia_lev1_94a_2019_01_01t00_00_11_12z_image_lev1.fits"]
+    amap = sunpy.map.Map(uri_list, fsspec_kwargs={'anon':True})
+    assert all(isinstance(am, sunpy.map.GenericMap) for am in amap)
 
 @pytest.mark.filterwarnings('ignore:File may have been truncated')
 @pytest.mark.parametrize(('file', 'mapcls'), [
