@@ -28,20 +28,17 @@ hekTime = a.Time(startTime, endTime)
 hekEvent = a.hek.EventType(eventType)
 
 
-@pytest.fixture(scope="function")
-@pytest.mark.remote_data
+@pytest.fixture()
 def h2v_client():
     return hek2vso.H2VClient()
 
 
-@pytest.fixture(scope="function")
-@pytest.mark.remote_data
+@pytest.fixture()
 def hek_client():
     return hek.HEKClient()
 
 
 @pytest.fixture
-@pytest.mark.remote_data
 def vso_client():
     vso.VSOClient()
 
@@ -145,7 +142,7 @@ def test_full_query(h2v_client, hek_client):
 @pytest.mark.remote_data
 def test_quick_clean(h2v_client, hek_client):
     h2v = h2v_client
-    h2v_q = h2v.full_query(
+    h2v.full_query(
         (a.Time(startTime, endTime), a.hek.EventType(eventType), a.hek.FL.PeakFlux > 1000)
     )
 
