@@ -22,6 +22,7 @@ from sunpy.physics.differential_rotation import (
     differential_rotate,
     solar_rotate_coordinate,
 )
+from sunpy.sun.constants import radius as R_sun
 from sunpy.util.exceptions import SunpyDeprecationWarning
 
 # Please note the numbers in these tests are not checked for physical
@@ -100,11 +101,11 @@ def test_solar_rotate_coordinate():
     new_observer = get_earth(new_time)
 
     # Test that when both the observer and the time are specified, an error is raised.
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="Either the 'observer' or the 'time' keyword must be specified, but not both simultaneously."):
         d = solar_rotate_coordinate(c, observer=observer, time=new_time)
 
     # Test that the code properly filters the observer keyword
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="The 'observer' must be an astropy.coordinates.BaseCoordinateFrame or an astropy.coordinates.SkyCoord."):
         d = solar_rotate_coordinate(c, observer='earth')
 
     # Test that the code properly filters the time keyword
@@ -168,7 +169,7 @@ def test_consistency_with_rotatedsunframe():
 def test_differential_rotate_observer_all_off_disk(all_off_disk_map):
     # Test a map that is entirely off the disk of the Sun
     # Should report an error
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="The entire map is off disk. No data to differentially rotate."):
         differential_rotate(all_off_disk_map)
 
 
@@ -251,7 +252,7 @@ def test_differential_rotate_time_off_disk(all_off_disk_map):
     # Test a map that is entirely off the disk of the Sun
     # Should report an error
     new_time = all_off_disk_map.date + 48*u.hr
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="The entire map is off disk. No data to differentially rotate."):
         differential_rotate(all_off_disk_map, time=new_time)
 
 
@@ -265,12 +266,12 @@ def test_get_new_observer(aia171_test_map):
 
     # The observer time is set along with other definitions of time
     for time in (rotation_interval, new_time, time_delta):
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="Either the 'observer' or the 'time' keyword must be specified, but not both simultaneously."):
             new_observer = _get_new_observer(initial_obstime, observer, time)
 
     # Obstime property is present but the value is None
     observer_obstime_is_none = SkyCoord(12*u.deg, 46*u.deg, frame=frames.HeliographicStonyhurst)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="The observer 'obstime' property must not be None."):
         new_observer = _get_new_observer(None, observer_obstime_is_none, None)
 
     # When the observer is set, it gets passed back out
@@ -297,7 +298,7 @@ def test_get_new_observer(aia171_test_map):
                                        observer.transform_to(frames.HeliographicStonyhurst).radius.to(u.au).value, decimal=3)
 
     # The observer and the time cannot both be None
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="Either the 'observer' or the 'time' keyword must not be None."):
         new_observer = _get_new_observer(initial_obstime, None, None)
 
 
@@ -349,7 +350,7 @@ def test_get_extreme_position():
         assert _get_extreme_position(coords, 'Tx', operator=np.nanmax) == 1
         assert _get_extreme_position(coords, 'Ty', operator=np.nanmax) == 2
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="The \"axis\" argument must be either \"Tx\" or \"Ty\""):
         _get_extreme_position(coords, 'lon', operator=np.nanmax)
 
 
@@ -391,3 +392,14 @@ def test_differential_rotation(aia171_test_map):
     with pytest.warns(UserWarning, match="Using 'time' assumes an Earth-based observer"):
         rot_map = differential_rotate(aia171_test_map, time=2*u.day)
     return rot_map.data
+
+
+def test_rsun_fallback(aia171_test_map):
+    # Remove the AIA-specific value of the solar radius
+    assert_quantity_allclose(aia171_test_map.rsun_meters, 696 * u.Mm)
+    del aia171_test_map.meta['rsun_ref'], aia171_test_map.meta['rsun_obs']
+
+    # Confirm that the differentially rotated map has the default value for the solar radius
+    new_observer = get_earth(aia171_test_map.date + 2 * u.day)
+    rot_map = differential_rotate(aia171_test_map, observer=new_observer)
+    assert_quantity_allclose(rot_map.rsun_meters, R_sun)
