@@ -11,9 +11,9 @@ import astropy.units as u
 from astropy.time import TimeDelta
 
 import sunpy.io
+import sunpy.io._file_tools
 from sunpy.time import parse_time
 from sunpy.timeseries.timeseriesbase import GenericTimeSeries
-from sunpy.util.decorators import deprecate_positional_args_since
 from sunpy.util.metadata import MetaDict
 from sunpy.visualization import peek_show
 
@@ -96,7 +96,6 @@ class GBMSummaryTimeSeries(GenericTimeSeries):
         return axes
 
     @peek_show
-    @deprecate_positional_args_since("4.1")
     def peek(self, *, title=None, columns=None, **kwargs):
         """
         Displays the GBM timeseries by calling
@@ -136,7 +135,7 @@ class GBMSummaryTimeSeries(GenericTimeSeries):
         filepath : `str`
             The path to the file you want to parse.
         """
-        hdus = sunpy.io.read_file(filepath)
+        hdus = sunpy.io._file_tools.read_file(filepath)
         return cls._parse_hdus(hdus)
 
     @classmethod
