@@ -1,3 +1,4 @@
+import re
 import copy
 import datetime
 from collections import OrderedDict
@@ -67,6 +68,11 @@ def truncation_slice_test_ts_4(eve_test_ts):
     )
 
 
+def test_repr_html(eve_test_ts):
+    with np.errstate(all='ignore'):
+        assert eve_test_ts._repr_html_() is not None
+
+
 def test_truncation_slices(eve_test_ts,
                            truncation_slice_test_ts_1, truncation_slice_test_ts_2,
                            truncation_slice_test_ts_3, truncation_slice_test_ts_4):
@@ -419,7 +425,7 @@ def test_remove_column(eve_test_ts):
     assert len(removed.columns) == removed.to_dataframe().shape[1]
 
     # Check that removing a non-existent column errors
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match=re.escape("Given column name (random column name) not in list of columns")):
         eve_test_ts.remove_column('random column name')
 
 
@@ -476,7 +482,7 @@ def test_empty_ts_invalid_peek(generic_ts):
     a = generic_ts.time_range.start - TimeDelta(2*u.day)
     b = generic_ts.time_range.start - TimeDelta(1*u.day)
     empty_ts = generic_ts.truncate(TimeRange(a, b))
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="The timeseries can't be plotted as it has no data present"):
         empty_ts.peek()
 
 
